@@ -5,10 +5,11 @@ use Apache2::Filter;
 use Apache2::Const -compile => qw(:common);
 use Apache2::RequestUtil;
 use Apache2::RequestRec;
+use Apache2::Response;
 use Apache2::Log;
 use URI::Escape;
 
-our $VERSION = '0.3.1';
+our $VERSION = '0.1';
 
 my $globalParams;
 
@@ -35,13 +36,10 @@ sub getParams {
                 &logError($r, "$paramFile content doesn't seem to be a valid perl hash");
                 $globalParams->{$paramFile} = 0;
             } else {
-                $params->{form}       ||= 'form:first';
-                $params->{submit}     ||= 'false';
-                $params->{javascript} ||= '';
-                $params->{publicFormData}   ||= {};
-                $params->{publicFilledData} ||= {};
-                $params->{secretFormData}   ||= {};
-                $params->{postDataSub}      ||= [];
+                $params->{form}   ||= 'form:first';
+                $params->{submit} ||= 'false';
+                $params->{secretFormData} ||= {};
+                $params->{publicFormData} ||= {};
                 %{ $params->{secretFormData} } = (
                     %{ $params->{publicFormData} },
                     %{ $params->{secretFormData} }
@@ -60,24 +58,14 @@ sub getParams {
 sub js {
     my $params = shift;
     my ($form, $submit) = ($params->{form}, $params->{submit});
-    eval "\$form = '$form'";
-    eval "\$submit = '$submit'";
+    eval "\$form = $form";
+    eval "\$submit = $submit";
     my $js = "  var form = jQuery('$form')\n"
            . "  form.attr('autocomplete', 'off')\n";
     while ( my ($name, $value) = each %{ $params->{publicFormData} } ) {
-        eval "\$value = '$value'";
+        eval "\$value = $value";
         $js .= "  form.find('input[name=$name], select[name=$name], textarea[name=$name]').val('$value')\n";
     }
-    while ( my ($name, $value) = each %{ $params->{publicFilledData} } ) {
-        eval "\$value = '$value'";
-        $js .= "  form.find('$name').val('$value')\n";
-    }
-    if ($params->{javascript}) {
-      my $javascript = $params->{javascript};
-      $javascript =~ s/"/\\"/g;
-      eval "\$javascript = '$javascript'";
-      $js .= "$javascript\n";
-    }
     $js .= $submit eq "true"  ? "  form.submit()\n"
          : $submit ne "false" ? "  form.find('$submit').click()\n"
          : "";
@@ -113,6 +101,7 @@ sub output {
         $f->r->subprocess_env;
         my $js = &js($params);
         $body =~ s/(<\/head>)/$js$1/i or $body =~ s/(<body>)/$1$js/i;
+        $f->r->set_content_length(length $body);
         $f->print($body);
     }
     return Apache2::Const::OK;
@@ -137,14 +126,11 @@ sub input {
     } else {
         $f->r->subprocess_env;
         while ( my ($name, $value) = each %{ $params->{secretFormData} } ) {
-            eval "\$value = '$value'";
+            eval "\$value = $value";
             $name  = uri_escape $name;
             $value = uri_escape $value;
             $body =~ s/$name=.*?((?:&|$))/$name=$value$1/;
         }
-        foreach my $sub ( @{ $params->{postDataSub} } ) {
-            eval "\$body =~ $sub";
-        }
         $f->print($body);
     }
     return Apache2::Const::OK;
@@ -159,15 +145,13 @@ ReverseProxy::FormFiller - Let Apache fill and submit any html form in place of
 
 =head1 VERSION
 
-Version 0.3.1
+Version 0.1
 
 =head1 SYNOPSIS
 
 ReverseProxy::FormFiller makes an Apache server, positioned as a frontal server or as a reverse-proxy, fill and (possibly) submit html forms in place of users.
 
-This is particularly intended for authentication forms, if you want users to be authenticated with some account, but if you don't want them to know and type any password. But it also works with any html POST form.
-
-ReverseProxy::FormFiller is based on Apache2 mod_perl filters. So, you have to enable mod_perl.
+This is particularly intended for authentication forms, if you want users to be authenticated with some account, but if you don't want them to know and type any password. But it also works with any html form.
 
 =head2 Basic Example
 
@@ -193,7 +177,6 @@ create an Apache virtualhost called myauth.example.com, looking like :
 
     <Location /login.php>
       RequestHeader unset Accept-Encoding
-      Header        unset Content-Length
       PerlOutputFilterHandler ReverseProxy::FormFiller::output
     </Location>
 
@@ -255,27 +238,6 @@ Assume you have two authentication forms in the same page, one for the morning a
     password => '$ENV{REMOTE_USER} =~ /(rtyler|msmith)/ ? "admin-secret" : "user-secret"',
   },
 
-=head2 Framework example
-
-Some applications based on frameworks either use HTTP without HTML (e.g Flash), or they send POST data out of any HTML form.
-
-This module allows to fill any HTML field from its jQuery selectors, thanks to the "publicFilledData" parameter.
-
-On the other hand, you can apply any substitution on POST datas, thanks to the "postDataSub" parameter - but it may require some tuning to get the right substitution PCRE.
-
-Here is an example from a real-life GWT application :
-
-  jQueryUrl => '//ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
-  form      => 'body',
-  submit    => 'button.genericButton',
-  publicFilledData => {
-    'input.gwt-TextBox'         => 'jdoe',
-    'input.gwt-PasswordTextBox' => 'fake',
-  },
-  postDataSub => [
-    's/jdoe\|fake/jdoe\|secret/'
-  ]
-
 
 =head1 Details of Apache config
 
@@ -305,23 +267,16 @@ When Apache has received the response from the remote server (if Apache is used
 Actually, this is done not by directly overwriting the form, but by including some javascript filling and submitting the form.
 
 This is done by the directive
-
   PerlOutputFilterHandler ReverseProxy::FormFiller::output
 
 Besides, ReverseProxy::FormFiller::output can not (or not yet) read zipped contents, so HTTP request headers "Content-encoding" have to be removed. This is done by the directive
-
   RequestHeader unset Accept-Encoding
 
-And ReverseProxy::FormFiller::output can not (or not yet) set Content-Length response header to the modified response body's length. So, remove Content-Length response header to avoid some bugs:
-
-  Header unset Content-Length
-
 For performances, it is better to handle only html pages containing the aimed form. So, you should place these directives in a container directive matching the form URL (as a <Location> directive), so as not to filter any html content.
 
 =head2 Filter request body
 
 When Apache receives a POST request from a client, it rewrites request POST body, replacing empty or fake data with secret data. This is done by the directive
-
   PerlInputFilterHandler  ReverseProxy::FormFiller::input
 
 For performances, it is better to handle only requests to the form "action" URL. So, you should place this directive in a container directive matching this URL (as a <Location> directive), so as not to filter any request.
@@ -340,23 +295,18 @@ Optional: if empty or not defined, jQuery is supposed to be already loaded in th
 
 jQuery selector to the form to fill.
 For example :
-
   form => "form#authForm",
 
 or
-
   form => "form:last",
 
 Optional: if empty or not defined, first form in web page will be filled - i.e.,
-
   form => "form:first",
 
 This field may rely on perl functions and Apache environment vars, e.g
-
   form => '(localtime)[2] >= 12 ? "#morningForm" : "#afternoonForm"',
 
 or
-
   form => '$ENV{REMOTE_USER} =~ /(rtyler|msmith)/ ? "#adminForm" : "#userForm"',
 
 =head2 submit
@@ -368,7 +318,6 @@ It may be "true" (autosubmit enabled), "false" (autosubmit disabled), or a jQuer
 Optional: if empty or not defined, autosubmit is disabled - that is, default value is "false".
 
 For example,
-
   submit => "true",
 
 or
@@ -383,75 +332,25 @@ Additionnaly, these fields will be controled in POST request when the form will
 As same as "submit" and "form" parameters, field values can rely on perl functions and Apache environment vars.
 
 For example,
-
   publicFormData => {
     company  => "SnakeOilsInc",
     user     => '$ENV{REMOTE_USER} =~ /(rtyler|msmith)/ ? "admin" : "user"',
     password => "hidden"
   },
 
-Note that these data are filled through jQuery method '.val()', so it works only with text inputs, password inputs, select tags and textarea, but not with checkboxes and radio buttons. In order to select on radio buttons or check on checkboxes, look at the "javascript" parameter.
+Note that these data are filled through jQuery method '.val()', so it works only with text inputs, password inputs, select tags and textarea, but not with checkbox and radio buttons.
 
-=head2 publicFilledData
-
-Input fields to fill, defined by jQuery selectors instead of their name attribute. This is useful if an input field has no name attribute.
-
-As same as publicFormData,
-* these data will be seen by users
-* field values can rely on perl functions and Apache environment vars
-* it works only with text inputs, password inputs, select tags and textarea.
-
-Unlike to publicFormData, these fields are note controled in POST request against malicious tampering of values.
-
-  publicFilledData => {
-    'textarea.company'     => "SnakeOilsInc",
-    'input#user'           => '$ENV{REMOTE_USER} =~ /(rtyler|msmith)/ ? "user" : $ENV{REMOTE_USER} =~ /dwho/ ? "admin" : "nobody"',
-    'input[type=password]' => "hidden"
-  }
-
-Parameters publicFormData and publicFilledData can be used together.
+But all inputs
 
 =head2 secretFormData
 
 Form fields to fill in request body, in addition or in overload to publicFormData. The main with between publicFormData is that these data will not be filled in the html form, so users can't see them.
 
 Field values can rely on perl functions and Apache environment vars.
-
   secretFormData => {
     password => '$ENV{REMOTE_USER} =~ /(rtyler|msmith)/ ? "admin-secret" : "user-secret"',
   },
 
-=head2 postDataSub
-
-Substitutions to apply to POST datas. Substitutions are defined with PCRE; they may use captures and may rely on Apache environment vars.
-
-Parameter postDataSub is an array ref and not a hash ref (unlike to publicFormData, publicFilledData and secretFormData). Hence substitutions are applied in the order they are defined.
-
-Basic example:
-  postDataSub => [
-    's/foo/bar/gi',
-  ]
-
-If POST data are made of colon-separated values and you want to change 5th value into "foo":
-  postDataSub => [
-    's/^((.+?:){4}).+?:/$1:foo:/'  # if POST data are made of :-separated values and you want to change 5th value into "foo"
-  ]
-
-In order to rewrite POST data so as to force jdoe's password to "jdoe-secret" and rtyler's to "rtyler-passwd", whereas these passwords are disclosed - assume POST data is '[login]:[password]'
-  postDataSub => [
-    's/^.*$/$ENV{REMOTE_USER}:$ENV{REMOTE_USER}/',
-    's/jdoe:jdoe/jdoe:jdoe-secret/',
-    's/rtyler:rtyler/rtyler:rtyler-passwd/'
-  ]
-
-=head2 javascript
-
-Arbitrary javascript code to run after fields are filled, but before posting the form.
-
-This javascript code can rely on perl functions and Apache environment vars. If you call jQuery through its shortcut '$', you have to escape it. Use single quotes and double quotes as in the example.
-
-  javascript => 'alert("Hello $ENV{REMOTE_USER}"); \$(input.mycheckbox).prop("checked", true)'
-
 =head1 AUTHOR
 
 FX Deltombe, C<< <fxdeltombe at gmail.com> >>
@@ -500,7 +399,7 @@ L<http://search.cpan.org/dist/ReverseProxy-FormFiller/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2014 FX Deltombe.
+Copyright 2013 FX Deltombe.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
